setup: Project StartR

Description Usage Examples

View source: R/setup.R

Description

Prints 'This is a R package that seeds your R analyses with a consistent folder structure. This allows all projects to operate identically, making collaboration, maintenance, and sharing easier and more scalable.'.

Usage

1

Examples

1

phdjsep/projectStartR documentation built on Sept. 25, 2020, 12:58 a.m.