Prints 'This is a R package that seeds your R analyses with a consistent folder structure. This allows all projects to operate identically, making collaboration, maintenance, and sharing easier and more scalable.'.
1 | setup()
|
1 | setup()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.